@@ -3,15 +3,9 @@ from django.conf import settings
 from django.core import mail
 from django.core.urlresolvers import reverse
 from django.test import TestCase
-from django.test.utils import override_settings
 
-EMAIL_ADMINS_SETTINGS = {
-    'ADMINS': (('Admin User', 'admin@example.com'),),
-    'ADMIN_HONEYPOT_EMAIL_ADMINS': True,
-}
 
 class AdminHoneypotTest(TestCase):
-    #urls = 'admin_honeypot.urls'
 
     def test_create_login_attempt(self):
         """
@@ -27,7 +21,7 @@ class AdminHoneypotTest(TestCase):
         self.assertEqual(data['password'], attempt.password)
         self.assertEqual(data['username'], unicode(attempt))
 
-    @override_settings(**EMAIL_ADMINS_SETTINGS)
+
     def test_email_admins(self):
         """
         An email is sent to settings.ADMINS
@@ -40,6 +34,7 @@ class AdminHoneypotTest(TestCase):
         self.assertTrue(len(mail.outbox) > 0) ## We sent at least one email...
         self.assertIn(settings.ADMINS[0][1], mail.outbox[0].to) ## ...to an admin
 
+
     def test_arbitrary_urls(self):
         """
         The Django admin displays a login screen for everything under /admin/
@@ -48,13 +43,21 @@ class AdminHoneypotTest(TestCase):
             'username': 'admin',
             'password': 'letmein',
         }
+        url_list = (
+            'auth/',
+            'comments/moderate/',
+            'flatpages/flatpage/?ot=desc&o=1'
+            'auth/user/1/',
+        )
         base_url = reverse('admin_honeypot')
-        for url in ('auth/', 'comments/moderate/', 'auth/user/1/'):
+        for url in url_list:
             response = self.client.post(base_url + url, data)
             attempt = LoginAttempt.objects.latest('pk')
+            self.assertEqual(base_url + url, attempt.path)
             self.assertEqual(data['username'], attempt.username)
             self.assertEqual(data['password'], attempt.password)
 
+
     def test_trailing_slash(self):
         """
         /admin/foo redirects to /admin/foo/ permanent redirect.
